@@ -10,6 +10,6 @@ __author__ = "Robert Kaussow"
 __project__ = "docker-tidy"
 __license__ = "Apache-2.0"
 __maintainer__ = "Robert Kaussow"
-__email__ = "mail@geeklabor.de"
-__url__ = "https://github.com/xoxys/docker-tidy"
+__email__ = "mail@thegeeklab.de"
+__url__ = "https://github.com/thegeeklab/docker-tidy"
 __version__ = metadata.version("docker-tidy")
